pub enum WorkspaceLeaseMode {
SharedRead,
ExclusiveWrite,
}Expand description
Lease mode. Write leases conflict with overlapping read or write leases.
Variants
Read access that tolerates other concurrent readers.
ExclusiveWrite
Write access that excludes any overlapping read or write lease.