pub struct GuardEvaluation { /* private fields */ }Expand description
Guard decision plus any evidence cassette recorded for a refusal.
Implementations
Sourceimpl GuardEvaluation
impl GuardEvaluation
Sourcepub fn decision(&self) -> &GuardDecision
pub fn decision(&self) -> &GuardDecision
Returns the guard decision.
Sourcepub fn cassette(&self) -> Option<&DevCassette>
pub fn cassette(&self) -> Option<&DevCassette>
Returns the evidence cassette recorded for a refusal, if any.