pub fn attribution_card(
run: Ref,
events: &EventLedger,
effects: &EffectLedger,
) -> Result<AttributionCard>Expand description
Builds an attribution card from the evidence for one run.
pub fn attribution_card(
run: Ref,
events: &EventLedger,
effects: &EffectLedger,
) -> Result<AttributionCard>Builds an attribution card from the evidence for one run.