install_agent_lib

Function install_agent_lib 

pub fn install_agent_lib(cx: &mut Cx) -> Result<()>
Installs the agent library into cx, pulling in the server lib, registering the agent address resolver and line driver, and loading AgentLib.