pub fn minimal_counterfactual(
records: &[SyntheticRecord],
source_id: &str,
desired_selected: bool,
) -> Result<Counterfactual>Expand description
Finds the nearest synthetic record with the desired outcome.
pub fn minimal_counterfactual(
records: &[SyntheticRecord],
source_id: &str,
desired_selected: bool,
) -> Result<Counterfactual>Finds the nearest synthetic record with the desired outcome.