pub fn reflect(
cx: &mut Cx,
output: &PlanningOutput,
runner: &dyn ModelRunner,
retry_budget: u32,
) -> Result<Reflection>Expand description
Critiques an output and runs at most one retry requested by the runner.
pub fn reflect(
cx: &mut Cx,
output: &PlanningOutput,
runner: &dyn ModelRunner,
retry_budget: u32,
) -> Result<Reflection>Critiques an output and runs at most one retry requested by the runner.